#!/usr/bin/ksh
#
# Ricoh AP2100
# LPD self-extracting installation script.
#
KIT_COPYRIGHT="Copyright (c) 2003 Hewlett-Packard Company"

KIT_APS=APS
KIT_LPD=LPD
KIT_MINVER="V5.1"
KIT_TYPE=$KIT_LPD
KIT_PRINTER="Ricoh AP2100"
KIT_FILES="ricohAP2100.rpd Ricoh_Laser_AP2100.lpd"

function setupInstructions {
    mimimumVersionTest V5.1B
    if [[ $? != 0 ]]
    then
	print "Use lprsetup(8) to create an /etc/printcap file entry, specifying" >&2
	print "the printer type "ln17". This creates the entry for your new printer." >&2
	print "Then edit the printcap entry and apply the following changes:" >&2
	print "" >&2
	print "	:if=/usr/lbin/ppdof +OPageSize=Letter +CricohAP2100.rpd:\\" >&2
	print "	:of=/usr/lbin/ppdof +OPageSize=Letter +CricohAP2100.rpd:\\" >&2
	print "	:pw#0:\\" >&2
    else
	print "Use lprsetup(8) to create a new /etc/printcap file entry. Driver" >&2
	print "updates will not impact the current /etc/printcap entries." >&2
    fi
    print "" >&2
    print "For additional information refer to printcap(4) \c" >&2
    if [[ ! -z `find /usr/man/man8/ -name ppdof\*` ]]
    then
	print "and ppdof(8) man pages." >&2
    else
	print "man page." >&2
    fi
}


# Function:
#	askUser Prompt
#
# Description:
#	Prompt for a yes/no response. Default response is no.
#
# Arguments:
#	$1 Prompt Text
#
# Returns:
#	0 User entered yes
#	1 User entered no
#
function askUser {

	print "$1? <Y/N> \c" >&2
	read Response

	case "$Response" in
	[Yy])	return 0
		;;
	[Yy][Ee][Ss])
		return 0
		;;
	*)	return 1
		;;
	esac
}

# Function:
#	wrapMsg Text
#
# Description:
#	Pipe text to fold utility to make sure it will fit
#	within 80 characters.
#
# Arguments:
#	$1 Text, Message Text
#
# Returns:
#	n/a

function wrapMsg {
	print "$1" | fold -s >&2
}

# Function:
#	printLicenseAgreement
#
# Description:
#	Print license agreement
#
# Arguments:
#	None
#
# Returns:
#	Exits when the user does not agree to the terms of the license.

function PrintLicenseAgreement {

    wrapMsg "${KIT_COPYRIGHT}. All rights reserved.\n"

    msg1="                HEWLETT-PACKARD SOFTWARE PRODUCT"
    msg2="                  \"AS IS\" WARRANTY STATEMENT"
    wrapMsg "$msg1\n$msg2\n"

    msg1="DISCLAIMER. TO THE EXTENT ALLOWED BY LOCAL LAW, THIS HP SOFTWARE"
    msg2="PRODUCT (\"SOFTWARE\") IS PROVIDED TO YOU \"AS IS\" WITHOUT WARRANTIES OR"
    msg4="CONDITIONS OF ANY KIND, WHETHER ORAL OR WRITTEN, EXPRESS OR IMPLIED."
    msg5="HP SPECIFICALLY DISCLAIMS ANY IMPLIED WARRANTIES OR CONDITIONS OF"
    msg6="MERCHANTABILITY, SATISFACTORY QUALITY, NON-INFRINGEMENT AND FITNESS"
    msg7="FOR A PARTICULAR PURPOSE. Some countries, states and provinces do not"
    msg8="allow exclusions of implied warranties or conditions, so the above"
    msg9="exclusion may not apply to you. You may have other rights that vary"
    msg10="from country to country, state to state, or province to province."
    wrapMsg "$msg1 $msg2 $msg3 $msg4 $msg5 $msg6 $msg7 $msg8 $msg9 $msg10 \n"

    msg1="LIMITATION OF LIABILITY. EXCEPT TO THE EXTENT PROHIBITED BY LOCAL LAW,"
    msg2="IN NO EVENT WILL HP OR ITS SUBSIDIARIES, AFFILIATES OR SUPPLIERS BE"
    msg3="LIABLE FOR DIRECT, SPECIAL, INCIDENTAL, CONSEQUENTIAL OR OTHER DAMAGES"
    msg4="(INCLUDING LOST PROFIT, LOST DATA, OR DOWNTIME COSTS), ARISING OUT OF"
    msg5="THE USE, INABILITY TO USE, OR THE RESULTS OF USE OF THE SOFTWARE,"
    msg6="WHETHER BASED IN WARRANTY, CONTRACT, TORT OR OTHER LEGAL THEORY, AND"
    msg7="WHETHER OR NOT ADVISED OF THE POSSIBILITY OF SUCH DAMAGES. Your use of"
    msg8="the Software is entirely at your own risk. Should the Software prove"
    msg9="defective, you assume the entire cost of all service, repair or"
    msg10="correction. Some countries, states and provinces do not allow the"
    msg11="exclusion or limitation of liability for incidental or consequential"
    msg12="damages, so the above limitation may not apply to you."
    wrapMsg "$msg1 $msg2 $msg3 $msg4 $msg5 $msg6 $msg7 $msg8 $msg9 $msg10 $msg11 $msg12 \n"

    msg1="NOTE. EXCEPT TO THE EXTENT ALLOWED BY LOCAL LAW, THESE WARRANTY TERMS"
    msg2="DO NOT EXCLUDE, RESTRICT OR MODIFY, AND ARE IN ADDITION TO, THE"
    msg3="MANDATORY STATUTORY RIGHTS APPLICABLE TO THE LICENSE OF THE SOFTWARE"
    msg4="TO YOU."
    wrapMsg "$msg1 $msg2 $msg3 $msg4 \n"

}

# Function:
#	fileVersionTest Version PathFilename
#
# Description:
#	Fetch and compare the file version.
#
# Arguments:
#	$1 Version, The version of the file in this script
#	$2 PathFilename, path/filename of file to test
#
# Returns:
#	0 Script file older than installed file
#	1 Script file the same as installed file
#	2 Script file newier than install file
#
function fileVersionTest {

	new_ver=$(fixVersion $1)

	base=$(basename $2)
	ext=$(basename $2 | cut -f2 -d'.')
	case $ext in
	lpd)
		# Version format: 1.1.2.4
		old_ver=$(grep 'Revision:' $2 | cut -f4 -d\$ | cut -f2 -d: )
		;;
	paf)
		# Version format: APX-1-001 or 100
		old_ver=$(grep 'paf-x-file-version' $2 | cut -f2 -d\= )
		;;
	pcf)
		# Version format: 1.1.2.4
		old_ver=$(grep 'Revision:' $2 | cut -f4 -d\$ | cut -f2 -d: )
		;;
	pfo)
		# The version is not provided in all the files.
		# Version format: 1.0
		old_ver=$(grep 'FileVersion' $2 | cut -f2 -d\: )
		[[ -z $old_ver ]] && old_ver="0.0"
		;;
	[rp]pd)
		# Version format: "1.0"
		old_ver=$(grep '\*FileVersion' $2 | cut -f2 -d\: )
		;;
	*)
		# Lpd print filter?
		old_ver=$(what $2 | tr -s '@' '\n' | grep $base | grep 'Revision:' | cut -f4 -d\$ | cut -f2 -d: )
		;;
	esac

	old_ver=$(fixVersion $old_ver)

	# Are the versions the same?
	if [[ $new_ver = $old_ver ]] 
	then	# Yes
		return 1
	fi

	if [[ $new_ver > $old_ver ]]
	then
		# New file more current
		return 2
	else
		# System file more current
		return 0
	fi
}

# Function:
#	checkSumTest PathFilename CheckSum1 CheckSum2
#
# Description:
#	Fetch and compare the file version.
#
# Arguments:
#	$1 PathFilename, path/filename
#	$2 CheckSum1,  First checksum value generated from the 'sum' command.
#	$3 CheckSum2,  Second checksum value generated from the 'sum' command.
#
# Returns:
#	0 Checksum matched
#	1 Checksum error
#
function checkSumTest {

	sum1=`sum $1 | tr -s "  " " " | cut -f 1 -d ' '`
	sum2=`sum $1 | tr -s "  " " " | cut -f 2 -d ' '`

	if [[ $sum1 -ne $2 ]] || [[ $sum2 -ne $3 ]]
	then
		return 1
	else
		return 0
	fi
}

# Function:
#	installTest FileVersion PathFilename CheckSum1 CheckSum2
#
# Description:
#	Test to see if the directory exists and the file
#	uuencoded file is newier than the system file.
#
# Arguments:
#	$1 FileVersion,  File version
#	$2 PathFilename, path/filename
#	$3 CheckSum1,  First checksum value generated from the 'sum' command.
#	$4 CheckSum2,  Second checksum value generated from the 'sum' command.
#
# Returns:
#	0 Install file, all tests passed
#	1 Don't install file, one or more tests failed
function installTest {
	mkdir=0

	# Can't install the file if the directory doesn't exist.

	file_name=`basename $2`
	directory=`dirname $2`

	if [[ ! -d $directory ]]
	then
		if [[ $mkdir = 0 ]]
		then
			msg1="Error: File $file_name not installed because"
			msg2="directory $directory doesn't exist."
			wrapMsg "$msg1 $msg2"
			return 1
		else
			mkdir $directory
			chmod 755 $directory
			chown root:system $directory
		fi
	fi

	# If the file does not exist, it's ok to install.
	if [[ ! -e $2 ]]
	then
		return 0
	fi

	fileVersionTest $1 $2
	status=$?

	if [[ $status = 1 ]]
	then
		checkSumTest $2 $3 $4
		if [[ $? = 0 ]]
		then
			# Files are the same, don't install
			wrapMsg "The $file_name system file is current and will not be replaced.\n"
			return 1
		else
			# Versions are the same, but the files are different!
			print "Warning: File versions match but the files are different!">&2
			askUser "Replace $file_name"
			return $?
		fi
	fi

	if [[ $status = 0 ]]
	then
		wrapMsg "The $file_name system file is newier and will not be replaced.\n"
		return 1
 	fi

	return 0
}

# Function:
#	mimimumVersionTest version
#
# Description:
#	Test to see if the minimum application or operating version 
#	requirement is met.
#
# Arguments:
#	$1 Version,    Minimum install version requirement
#
# Returns:
#	0 test passed
#	1 test failed
#
function mimimumVersionTest {

	if [[ $KIT_TYPE = $KIT_APS ]]
	then
		# At this time there isn't a minimum APS requirement.
		return 0 
	fi

	# The only other kit type is LPD, so check the OS version.

	# Note: The version field moves 1 position between Digital UNIX
	#       and Compaq Tru64 UNIX, but is always before (Rev.
	temp=` strings /vmunix | grep '(Rev.' | grep UNIX | cut -f1 -d '(' `

	# The version is the last value
	for x in $temp
	{
	  osver=$x
	}

	# A field test version of the OS might not start with a V. At some
	# point we might need to note the difference, but for now we don't.
	# Modify the version string by replacing the first character with a V.

	temp=$osver
	osver="V$( echo "$osver" | cut -c2- )"

	if [[ $osver < $1 ]]
	then
		return 1
	fi

	return 0
}

# Function:
#	installLpdTest FileVersion PathFilename CheckSum1 CheckSum2
#
# Description:
#	If the file does not currently exist and the minimal install
#	requirements are met, a success status is returned.
#
# Arguments:
#	$1 FileVersion,  File version
#	$2 PathFilename, path/filename
#	$3 CheckSum1,  First checksum value generated from the 'sum' command.
#	$4 CheckSum2,  Second checksum value generated from the 'sum' command.
#
# Exits:
#	Exit if the minimum OS requirement is not met.
#
# Returns:
#	0 Install file, all tests passed
#	1 Don't install file, one or more tests failed
#
function installLpdTest {

	file_name=`basename $2`
	file_ext=`print "$file_name" | cut -f2 -d'.'`

	# Perform the OS test after this test. No reason to complain
	# about the os version if the file isn't going to be installed.
	if [[ $file_ext = "lpd" ]]
	then
		# If this is a .lpd file and the base directory doesn't exist
		# return.
		if [[ ! -d `dirname $2` ]]
		then
			msg1="File $file_name is not required for this version of Tru64 UNIX.\n"
			wrapMsg "$msg1"
			return 1
		fi
	fi

	installTest $1 $2 $3 $4
	return $?
}


# Function:
#	installApsTest FileVersion PathFilename CheckSum1 CheckSum2
#
# Description:
#	Test the minimal install requirements for an APS file. 
#
# Arguments:
#	$1 File version, File version
#	$2 PathFilename, path/filename
#	$3 CheckSum1,  First checksum value generated from the 'sum' command.
#	$4 CheckSum2,  Second checksum value generated from the 'sum' command.
#
# Returns:
#	0 Install file, all tests passed
#	1 Don't install file, one or more tests failed
#

function installApsTest {

	installTest $1 $2 $3 $4
	return $?
}

# Function:
#	fixVersion Version
#
# Description:
#	Remove unwanted characters.
#	Aps two version formats are converted to a common format.
#
# Arguments:
#	$1 Version, Version string
#
# Returns:
#	The updated version string.
#
function fixVersion {

	# Remove quotes, tabs, and spaces
	ver=$(echo $1 | tr -d "\"\t ")

	# Set null strings to version 0
	if [[ -z $ver ]]
	then
		ver=0
	fi

	# If the version starts with 'a', convert
	# a???-x-xxx to xxxx
	case $ver in
	[Aa]*)	;;
	[0123456789]*)
		# Return the version
		print "$ver"
		return
		;;
	*)	# Don't know what we found so return a version of 0.
		print "0.0"
		;;
	esac

	# To compare version 100 to apx-?-??? convert
	# apx-1-001 to 1001
	# apx-1-2   to 1002
	part1=$(echo "$ver" | cut -f2 -d\-)
	part2=$(echo "$ver" | cut -f3 -d\-)

	ver=$(printf "%s%.3d" $part1 $part2)

	# Return the version
	print "$ver"
	return
}

# Function:
#	preInstall FileVersion PathFilename CheckSum1 CheckSum2
#
# Description:
#	Determine if this is an APS or LPD install and call the
#	appropriate function.
#
# Arguments:
#	$1 FileVersion,  File version
#	$2 PathFilename, path/filename
#	$3 CheckSum1,  First checksum value generated from the 'sum' command.
#	$4 CheckSum2,  Second checksum value generated from the 'sum' command.
#
# Returns:
#	0 Install file
#	1 Don't install file
#
function preInstall {

	status=1

	if [[ $KIT_TYPE = $KIT_LPD ]] 
	then
		installLpdTest $1 $2 $3 $4
		status=$?
	fi

	if [[ $KIT_TYPE = $KIT_APS ]] 
	then
		installApsTest $1 $2 $3 $4
		status=$?
	fi

	# On install status, backup existing file
	# if it exists
	if [[ $status = 0 ]]
	then
		if [[ -e $2 ]]
		then
			# format = filename_yyyymmmdd_hh:mm:ss
			backup=$2_$(date +"b%d_%T")
			mv $2 $backup
			wrapMsg "Backup file $backup created."

			# Return the name of the backup file
			print "$backup"
		fi
	fi
	return $status
}

# Function:
#	postInstall BackupFile Owner Group Protection FileName CheckSum1 CheckSum2
#
# Description:
#	After the file has been installed verify the file checksum. If
#	the checksum is ok, set the file owner and protection.
#
#	Notify the user of a checksum error and prompt to remove the file.
#
# Arguments:
#	$1 BackupFile, Name of the backup file
#	$2 Owner,      File owner for chown command
#	$3 Group,      Group owner for chgrp command
#	$4 Protection, File protections number, eg 644, for chmod command
#	$5 FileName,   Installed file path/filename
#	$6 CheckSum1,  First checksum value generated from the 'sum' command.
#	$7 CheckSum2,  Second checksum value generated from the 'sum' command.
#
# Returns:
#	None
#
function postInstall {

	chown $2:$3 $5
	chmod $4 $5

	checkSumTest $5 $6 $7
	if [[ $? != 0 ]]
	then
		wrapMsg "Install checksum error on file $5!"

		if [[ ! -z $1 ]]
		then
			askUser "Restore the backup file"
		else
			askUser "Delete the file $5"
		fi

		if [[ $? = 0 ]]
		then 
			rm $5
			if [[ ! -z $1 ]]
			then
				mv $1 $5
				wrapMsg "Backup file restored.\n"
			else
				wrapMsg "File $5 deleted.\n"
			fi
		fi
	else
		wrapMsg "File $5 installed.\n"
		FileInstalled=1
	fi
	return
}

# Function:
#	doHelp
#
# Description:
#	Display the install script options.
#
# Arguments:
#	None
#
# Returns:
#	None
#
function doHelp {
	print "Synopsis: $(basename $0) -option" >&2
	print "" >&2
	print "Options:  -i Install files" >&2
	print "          -p Printer configuration instructions" >&2
	print "" >&2
	return
}

#
# Program
#

typeset -xi FileInstalled=0

# Identify the program

if [[ $KIT_TYPE = $KIT_LPD ]]
then
	print "LPD \c"

elif [[ $KIT_TYPE = $KIT_APS ]]
then
	print "Advanced Printing Software \c"
fi

print "installation kit for: $KIT_PRINTER\n"


# When no arguments are provided, display the help text and exit.
if [[  $# = 0 ]]
then
	doHelp
	exit 0
fi

while getopts :hip opt
do
        case $opt in
	h)	doHelp
		exit 0
		;;
	i)	# Install, fall out of case statement
		;;
	p)	# Print post-install setup instructions
		setupInstructions
		exit 0
		;;
	\?)	doHelp
		exit 0
                ;;
        esac
done

UserName=`whoami`

if [[ $UserName != "root" ]]
then
	print "You must be root to run this program."
	exit 1
fi

mimimumVersionTest $KIT_MINVER
if [[ $? != 0 ]]
then
	msg1="This installation requires a minimum"
	msg2="operating system version of $1."
	wrapMsg "$msg1 $msg2"
	exit 1
fi

subset_name=UNKNOWN
if [[ $KIT_TYPE = $KIT_LPD ]]
then
	subset_name=OSFPRINT
elif [[ $KIT_TYPE = $KIT_APS ]]
then
	subset_name=APXBASE
else
	print "Error: Unknown kit type."
	exit 1
fi

if [ ! -e /usr/.smdb./$subset_name*.lk ]
then
	print "The update requires the $subset_name subset to be installed."
	exit 1
fi

print "This kit contains the following files:\n"

echo "$KIT_FILES" | fold -s
print ""

PRESS_ENTER='Press ENTER to continue'

printf "$PRESS_ENTER"
read temp

PrintLicenseAgreement 2>&1 | pg -e -p "$PRESS_ENTER" >&2

askUser "Do you accept the terms in the license agreement"
if [[ $? != 0 ]]
then
	# User did not accept license agreement.
	print "No files were installed."
	exit 1
fi
print "\n\n"

#--- uuencoded files ---
backup_file=$(preInstall "1.0" /usr/lbin/ppd/ricohAP2100.rpd 59191 3)
if [[ $? = 0 ]]
then
uudecode << 'EndOfEncodedFile'
begin 644 /usr/lbin/ppd/ricohAP2100.rpd
M*D9I;&5697)S:6]N.B`B,2XP(@HJ4')O9'5C=#H@(BA224-/2"!,05-%4B!!
M4#(Q,#`@("`@("`@("`@("`@("DB"BI-;V1E;$YA;64Z(")2:6-O:"!,87-E
M<B!!4#(Q,#`B"BI04U9E<G-I;VXZ("(H.#`N,#$Q*2`Q(@HJ3&%N9W5A9V5,
M979E;#H@(C(B"BI00T9I;&5.86UE.B`B<FEC;VA!4#(Q,#`N<G!D(@HJ2D-,
M0F5G:6XZ("(\,6(^)2TQ,C,T-5A`4$I,($I/0B(**DI#3%1O4%-);G1E<G!R
M971E<CH@(D!02DP@14Y415(@3$%.1U5!1T4@/2!03U-44T-225!4(@HJ2D-,
M16YD.B`B/#%B/B4M,3(S-#580%!*3"!%3THB"BI/<F1E<D1E<&5N9&5N8WDZ
M(#,P($%N>5-E='5P("I086=E4VEZ90HJ4&%G95-I>F4@030O030@,C$P('@@
M,CDW(&UM.B`B/#PO4&%G95-I>F4@6S4Y-2`X-#)=("]);6%G:6YG0D)O>"!N
M=6QL/CX@<V5T<&%G961E=FEC92(**E!A9V53:7IE($QE9V%L+TQE9V%L(#@@
M,2\R('@@,30@:6XZ("(\/"]086=E4VEZ92!;-C$R(#$P,#A=("]);6%G:6YG
M0D)O>"!N=6QL/CX@<V5T<&%G961E=FEC92(**E!A9V53:7IE($QE='1E<B],
M971T97(@."`Q+S(@>"`Q,2!I;CH@(CP\+U!A9V53:7IE(%LV,3(@-SDR72`O
M26UA9VEN9T)";W@@;G5L;#X^('-E='!A9V5D979I8V4B"BI086=E4VEZ92!4
M86)L;VED+U1A8FQO:60@,3$@>"`Q-R!I;CH@(CP\+U!A9V53:7IE(%LW.3(@
M,3(R-%T@+TEM86=I;F="0F]X(&YU;&P^/B!S971P86=E9&5V:6-E(@HJ4&%P
M97)$:6UE;G-I;VX@030Z("(U.34@.#0R(@HJ4&%P97)$:6UE;G-I;VX@3&5G
M86PZ("(V,3(@,3`P."(**E!A<&5R1&EM96YS:6]N($QE='1E<CH@(C8Q,B`W
M.3(B"BI087!E<D1I;65N<VEO;B!486)L;VED.B`B-SDR(#$R,C0B"BI);6%G
M96%B;&5!<F5A($$T.B`B,3(N,#`@,3(N,#`@-3@S+C`X(#@R.2XU-B(**DEM
M86=E86)L94%R96$@3&5G86PZ("(Q,BXP,"`Q,BXP,"`U.3DN.#@@.3DV+C`P
M(@HJ26UA9V5A8FQE07)E82!,971T97(Z("(Q,BXP,"`Q,BXP,"`U.3DN.#@@
M-S<Y+C@X(@HJ26UA9V5A8FQE07)E82!486)L;VED.B`B,3(N,#`@,3(N,3(@
M-S<Y+C@X(#$R,3(N,#`B"BI/<F1E<D1E<&5N9&5N8WDZ(#(P($%N>5-E='5P
M("I);G!U=%-L;W0**B4@3F]T93H@4')I;G1E<B!D;V5S(&YO="!P<F]V:61E
M(&UA;G5A;"!I;G!U="!W:71H('!A=7-E+@HJ)2`@("`@("!$;R!N;W0@<V5T
M($UA;G5A;$9E960@5')U90HJ26YP=713;&]T(&UA;G5A;"]">7!A<W,@5')A
M>3H@(CP\+TUA;G5A;$9E960@9F%L<V4@+U1R87E3=VET8V@@9F%L<V4*("`@
M("]-961I85!O<VET:6]N(#`^/B!S971P86=E9&5V:6-E(@HJ26YP=713;&]T
M('1R87DQ+U-T86YD87)D(%!A<&5R(%1R87DZ("(\/"]-86YU86Q&965D(&9A
M;'-E("]4<F%Y4W=I=&-H(&9A;'-E"B`@("`O365D:6%0;W-I=&EO;B`Q/CX@
M<V5T<&%G961E=FEC92(**DEN<'5T4VQO="!T<F%Y,B]/<'1I;VYA;"!087!E
M<B!4<F%Y.B`B/#PO36%N=6%L1F5E9"!F86QS92`O5')A>5-W:71C:"!F86QS
M90H@("`@+TUE9&EA4&]S:71I;VX@,CX^('-E='!A9V5D979I8V4B"BI);G!U
M=%-L;W0@=')A>3,O3W!T:6]N86P@4&%P97(@5')A>3H@(CP\+TUA;G5A;$9E
M960@9F%L<V4@+U1R87E3=VET8V@@9F%L<V4*("`@("]-961I85!O<VET:6]N
M(#,^/B!S971P86=E9&5V:6-E(@HJ1F]N="!!=F%N=$=A<F1E+4)O;VLZ("(B
M"BI&;VYT($%V86YT1V%R9&4M0F]O:T]B;&EQ=64Z("(B"BI&;VYT($%V86YT
M1V%R9&4M1&5M:3H@(B(**D9O;G0@079A;G1'87)D92U$96UI3V)L:7%U93H@
M(B(**D9O;G0@0F]O:VUA;BU$96UI.B`B(@HJ1F]N="!";V]K;6%N+41E;6E)
M=&%L:6,Z("(B"BI&;VYT($)O;VMM86XM3&EG:'0Z("(B"BI&;VYT($)O;VMM
M86XM3&EG:'1)=&%L:6,Z("(B"BI&;VYT($-O=7)I97(Z("(B"BI&;VYT($-O
M=7)I97(M0F]L9#H@(B(**D9O;G0@0V]U<FEE<BU";VQD3V)L:7%U93H@(B(*
M*D9O;G0@0V]U<FEE<BU/8FQI<75E.B`B(@HJ1F]N="!(96QV971I8V$Z("(B
M"BI&;VYT($AE;'9E=&EC82U";VQD.B`B(@HJ1F]N="!(96QV971I8V$M0F]L
M9$]B;&EQ=64Z("(B"BI&;VYT($AE;'9E=&EC82U.87)R;W<Z("(B"BI&;VYT
M($AE;'9E=&EC82U.87)R;W<M0F]L9#H@(B(**D9O;G0@2&5L=F5T:6-A+4YA
M<G)O=RU";VQD3V)L:7%U93H@(B(**D9O;G0@2&5L=F5T:6-A+4YA<G)O=RU/
M8FQI<75E.B`B(@HJ1F]N="!(96QV971I8V$M3V)L:7%U93H@(B(**D9O;G0@
M3F5W0V5N='5R>5-C:&QB:RU";VQD.B`B(@HJ1F]N="!.97=#96YT=7)Y4V-H
M;&)K+4)O;&1)=&%L:6,Z("(B"BI&;VYT($YE=T-E;G1U<GE38VAL8FLM271A
M;&EC.B`B(@HJ1F]N="!.97=#96YT=7)Y4V-H;&)K+5)O;6%N.B`B(@HJ1F]N
M="!086QA=&EN;RU";VQD.B`B(@HJ1F]N="!086QA=&EN;RU";VQD271A;&EC
M.B`B(@HJ1F]N="!086QA=&EN;RU)=&%L:6,Z("(B"BI&;VYT(%!A;&%T:6YO
M+5)O;6%N.B`B(@HJ1F]N="!4:6UE<RU";VQD.B`B(@HJ1F]N="!4:6UE<RU"
M;VQD271A;&EC.B`B(@HJ1F]N="!4:6UE<RU)=&%L:6,Z("(B"BI&;VYT(%1I
.;65S+5)O;6%N.B`B(@HJ
`
end
EndOfEncodedFile
postInstall "$backup_file" bin bin 644 /usr/lbin/ppd/ricohAP2100.rpd 59191 3
fi

backup_file=$(preInstall "1.1.4.1" /usr/lbin/lprsetup/Ricoh_Laser_AP2100.lpd 06445 1)
if [[ $? = 0 ]]
then
uudecode << 'EndOfEncodedFile'
begin 644 /usr/lbin/lprsetup/Ricoh_Laser_AP2100.lpd
M(R!`*",I)%)#4V9I;&4Z(%)I8V]H7TQA<V5R7T%0,C$P,"YL<&0L=B`D("12
M979I<VEO;CH@,2XQ+C0N,2`D("1$871E.B`R,#`Q+S`Y+S$Y(#$X.C`T.C4P
M("0*<')I;G1E<CI<"B`@("`Z4$X]4FEC;V@@3&%S97(@05`R,3`P.EP*("`@
M(#IB<CTY-C`P.EP*("`@(#IF8STP,3<W-S<W.EP*("`@(#IF<STP,SI<"B`@
M("`Z:68]+W5S<B]L8FEN+W!P9&]F("M/4&%G95-I>F4]3&5T=&5R("M#<FEC
M;VA!4#(Q,#`N<G!D.EP*("`@(#IO9CTO=7-R+VQB:6XO<'!D;V8@*T]086=E
M4VEZ93U,971T97(@*T-R:6-O:$%0,C$P,"YR<&0Z7`H@("`@.GAF/2]U<W(O
M;&)I;B]X9CI<"B`@("`Z;7@],#I<"B`@("`Z<&P]-C8Z7`H@("`@.G!W/3`Z
M7`H@("`@.G)W/6]N.EP*("`@(#IX8STP,3<W-S<W.EP*("`@(#IX<STP-#0P
M,#`Z7`H@("`@.E!$/5QN7`I4:&4@4FEC;V@@3&%S97(@05`R,3`P(&ES(&$@
J,C$@<'!M(%!#3"!A;F0@4&]S=%-C<FEP="!P<FEN=&5R+EP*7&Y<;CH*
`
end
EndOfEncodedFile
postInstall "$backup_file" bin bin 644 /usr/lbin/lprsetup/Ricoh_Laser_AP2100.lpd 06445 1
fi

mimimumVersionTest V5.1B
if [[ $? = 0 ]] && [[ $FileInstalled > 0 ]]
then
    if [[ -z $(/usr/sbin/lprsetup -c update) ]]
    then
        print "File /etc/lprsetup.dat was backed up then updated."
    fi
fi
exit 0
